"""
INPUT FILE FOR NLFEA OF BEAM B1 IN (Kotsovos, M.D. (1982): A fundamental explanation of the
behaviour of reinforced concrete beams in flexure based on the properties of concrete
uncer multiaxial stress. Materials and Structures, 15(90), 529-537).
"""

# OPEN NEW PROJECT
closeProject()
newProject( "Master_NLFEA", 10 )
setModelAnalysisAspects( [ "STRUCT" ] )
setModelDimension( "2D" )
setDefaultMeshOrder( "QUADRATIC" )					
setDefaultMesherType( "HEXQUAD" )				
setUnit( "LENGTH", "MM" )
setUnit( "FORCE", "N" )


# INITIALIZE SHAPE LIST AND SHAPE NUMBERING
SHAPELIST = []
SHAPENUMBER = 1
SELTOL = 0.01

from TOP_FUNC import A_TOP as A_TOP
import os
from math import pi


# GEOMETRY and PARAMETERS
STEELPLATE_T = 40									
OVERHANG = 100.0
SUPPORTPLATE = 150
X1 = 210
WEBOPENING_H = 90.0									
LOADPLATE = 150
X2 = 60
SUPPORTPLATE2 = 150.0
ENDPLATE = 100
X3 = 170
WEBOPENING_V = 60									
X4 = 270
L = 720

HEIGHT = 600
WIDTH = 160.0

PRESCRIBEDDISPLACEMENT = -2 					


#REINFORCEMENT
#Longitudinal Reinforcement (Top and bottom)
DIAMLONG = 19
ASLONG = ((pi/4)*DIAMLONG**2)*3
#Web Reinforcement
DIAMVERTICAL = 19
ASVERTICAL = ((pi/4)*DIAMVERTICAL**2)*2
COVER = 35 										


ELEMENTSIZE = HEIGHT/12 						

#MATERIAL PARAMETERS							
YOUNGSMOD = 39000								
POISSONRATIO = 0.15 							
POISSONRATIO_STEEL = 0.3 						
FC = 68.2 										
FCT = 4.35										
Fck= 60.2 										
GF = 0.1561 									
GC = 39.025 									
BETA = 0.01										
FY = 560.0
FY_STEELPLATE = 355

ES = 210000.0
ES_STEELPLATE = 210000
EHTOT = 4200.0  								
EPSMAX = 0.1   									



# ESTABLISH LISTS WITH COORDINATES					#COORD NUMBER:
XCOORD = [0]										#1
XCOORD.append(XCOORD[0]+STEELPLATE_T)				#2
XCOORD.append(XCOORD[1]+OVERHANG)					#3
XCOORD.append(XCOORD[2]+SUPPORTPLATE/2)				#4
XCOORD.append(XCOORD[3]+SUPPORTPLATE/2)				#5
XCOORD.append(XCOORD[4]+X1)							#6
XCOORD.append(XCOORD[5]+LOADPLATE/2)				#7
XCOORD.append(XCOORD[6]+LOADPLATE/2)				#8
XCOORD.append(XCOORD[7]+X2)							#9
XCOORD.append(XCOORD[8]+WEBOPENING_H)				#10
XCOORD.append(XCOORD[9]+X2)							#11
XCOORD.append(XCOORD[10]+SUPPORTPLATE2/2)			#12
XCOORD.append(XCOORD[11]+SUPPORTPLATE2/2)			#13
XCOORD.append(XCOORD[12]+X2)						#14
XCOORD.append(XCOORD[13]+WEBOPENING_H)				#15
XCOORD.append(XCOORD[14]+X2)						#16
XCOORD.append(XCOORD[15]+LOADPLATE/2)				#17
XCOORD.append(XCOORD[16]+LOADPLATE/2)				#18
XCOORD.append(XCOORD[17]+X1)						#19
XCOORD.append(XCOORD[18]+SUPPORTPLATE/2)			#20
XCOORD.append(XCOORD[19]+SUPPORTPLATE/2)			#21
XCOORD.append(XCOORD[20]+OVERHANG)					#22
XCOORD.append(XCOORD[21]+STEELPLATE_T)				#23

YCOORD = [0]										#1
YCOORD.append(YCOORD[0]+STEELPLATE_T)				#2
YCOORD.append(YCOORD[1]+ENDPLATE)					#3
YCOORD.append(YCOORD[2]+X3)							#4
YCOORD.append(YCOORD[3]+WEBOPENING_V)				#5
YCOORD.append(YCOORD[4]+X4)							#6
YCOORD.append(YCOORD[5]+STEELPLATE_T)				#7


# CREATE GEOMETRY
SHAPENUMBER = 1
SHAPELIST = []
#Concrete
SHAPENUMBER,SHAPELIST = A_TOP(2,2,20,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(2,3,20,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(2,4,7,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(10,4,4,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(15,4,7,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(2,5,20,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
#Steelplates
SHAPENUMBER,SHAPELIST = A_TOP(6,6,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(16,6,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(3,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(11,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(19,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
fitAll()


# LONGITUDINAL REINFORCEMENT
P1 = [XCOORD[1],YCOORD[1]+COVER,0]
P2 = [XCOORD[21],YCOORD[1]+COVER,0]
createLine( 'LONGREINFBOTTOM', P1, P2 )
P1 = [XCOORD[1]+25, YCOORD[5]-200, 0]
P2 = [XCOORD[1]+25,YCOORD[5]-COVER,0]
P3 = [XCOORD[21]-25,YCOORD[5]-COVER,0]
P4 = [XCOORD[21]-25, YCOORD[5]-200, 0]
createLine( 'LONGREINFTOP1',  P1, P2 )
createLine( 'LONGREINFTOP2',  P2, P3 )
createLine( 'LONGREINFTOP3',  P3, P4 )

LONGREINFBOTTOM = ['LONGREINFBOTTOM']
LONGREINFTOP = ['LONGREINFTOP1', 'LONGREINFTOP2', 'LONGREINFTOP3']


# VERTICAL WEB REINFORCEMENT
S1 = [XCOORD[1]+COVER,YCOORD[1]+COVER-DIAMVERTICAL,0]
S2 = [XCOORD[1]+COVER,YCOORD[5]-COVER+DIAMVERTICAL,0]
createLine( 'VERTREINF1', S1, S2 )
S1 = [XCOORD[1]+COVER*2,YCOORD[1]+COVER-DIAMVERTICAL,0]
S2 = [XCOORD[1]+COVER*2,YCOORD[5]-COVER+DIAMVERTICAL,0]
createLine( 'VERTREINF2', S1, S2 )
S1 = [XCOORD[21]-COVER,YCOORD[1]+COVER-DIAMVERTICAL,0]
S2 = [XCOORD[21]-COVER,YCOORD[5]-COVER+DIAMVERTICAL,0]
createLine( 'VERTREINF3', S1, S2 )
S1 = [XCOORD[21]-COVER*2,YCOORD[1]+COVER-DIAMVERTICAL,0]
S2 = [XCOORD[21]-COVER*2,YCOORD[5]-COVER+DIAMVERTICAL,0]
createLine( 'VERTREINF4', S1, S2 )
S1 = [XCOORD[11],YCOORD[1]+COVER-DIAMVERTICAL,0]
S2 = [XCOORD[11],YCOORD[5]-COVER+DIAMVERTICAL,0]
createLine( 'VERTREINF5', S1, S2 )

STIRRUPS= ['VERTREINF1', 'VERTREINF2', 'VERTREINF3', 'VERTREINF4', 'VERTREINF5']


# DEFINE PROPERTIES FOR THE CONCRETE GEOMETRY AND MATERIAL
# TOTAL STRAIN FIXED CRACKING

addMaterial( "Concrete", "CONCR", "TSCR", [] )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/YOUNG", YOUNGSMOD )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/POISON", POISSONRATIO )

setParameter( MATERIAL, "Concrete", "MODTYP/TOTCRK", "FIXED" )				
setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "PARABO" )			
setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", FC )
setParameter( MATERIAL, "Concrete", "COMPRS/GC", GC )
setParameter( MATERIAL, "Concrete", "COMPRS/CONFIN/CNFCRV", "VECCHI" )
setParameter( MATERIAL, "Concrete", "COMPRS/REDUCT/REDCRV", "VC1993" )

setParameter( MATERIAL, "Concrete", "TENSIL/TENCRV", "MC2010" )
setParameter( MATERIAL, "Concrete", "TENSIL/TENSTR", FCT )
setParameter( MATERIAL, "Concrete", "TENSIL/GF1", GF ) 
setParameter( MATERIAL, "Concrete", "TENSIL/POISRE/POIRED", "DAMAGE" )		

setParameter( MATERIAL, "Concrete", "SHEAR/SHRCRV", "DAMAGE" )				
# setParameter( MATERIAL, "Concrete", "SHEAR/SHRCRV", "CONSTA" )
# setParameter( MATERIAL, "Concrete", "SHEAR/BETA", BETA ) 

CONMATNAME = "Concrete"
addGeometry( CONMATNAME, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, CONMATNAME, "THICK", WIDTH )

assignMaterial( CONMATNAME, "SHAPE", SHAPELIST[0:78] )
assignGeometry( CONMATNAME, "SHAPE", SHAPELIST[0:78] )



# DEFINE PROPERTIES FOR THE STEEL GEOMETRY AND MATERIAL
# TOTAL STRAIN FIXED CRACKING
addMaterial( "Steelplate", "MCSTEL", "TRESCA", [] )
setParameter( MATERIAL, "Steelplate", "TREPLA/YIELD", "VMISES" )
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/YOUNG", ES_STEELPLATE )
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/POISON", POISSONRATIO_STEEL )
setParameter( MATERIAL, "Steelplate", "TREPLA/YLDSTR", FY_STEELPLATE )

STEELMATNAME = "Steelplate"
addGeometry( STEELMATNAME, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, STEELMATNAME, "THICK", WIDTH )

assignMaterial( STEELMATNAME, "SHAPE", SHAPELIST[78:88] )
assignGeometry( STEELMATNAME, "SHAPE", SHAPELIST[78:88] )


# DEFINE PROPERTIES FOR THE REINFORCEMENT GEOMETRY AND MATERIAL
setReinforcementAspects( LONGREINFBOTTOM )
setReinforcementAspects( LONGREINFTOP )
setReinforcementAspects( STIRRUPS )
RMATNAME_LONGREINF = "Longitudinal reinforcement"
SMATNAME_STIRR = "Vertical stirrups"


SMAX = FY + EHTOT*(EPSMAX - FY/ES)										
EPSPLMAX = EPSMAX*(1-EHTOT/ES) + FY/ES*(EHTOT/ES - 1)

addMaterial( RMATNAME_LONGREINF, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_LONGREINF, "LINEAR/ELASTI/YOUNG", ES )
setParameter( MATERIAL, RMATNAME_LONGREINF, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_LONGREINF, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, RMATNAME_LONGREINF, "PLASTI/HARDI2/KAPSIG", [ 0, FY, EPSPLMAX, SMAX ] )

addMaterial( SMATNAME_STIRR, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_STIRR, "LINEAR/ELASTI/YOUNG", ES )
setParameter( MATERIAL, SMATNAME_STIRR, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_STIRR, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, SMATNAME_STIRR, "PLASTI/HARDI2/KAPSIG", [ 0, FY, EPSPLMAX, SMAX ] )

addGeometry( RMATNAME_LONGREINF, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_LONGREINF, "CROSSE", ASLONG )

addGeometry( SMATNAME_STIRR, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_STIRR, "CROSSE", ASVERTICAL )

assignMaterial( RMATNAME_LONGREINF, "SHAPE", LONGREINFBOTTOM )
assignGeometry( RMATNAME_LONGREINF, "SHAPE", LONGREINFBOTTOM )

assignMaterial( RMATNAME_LONGREINF, "SHAPE", LONGREINFTOP )
assignGeometry( RMATNAME_LONGREINF, "SHAPE", LONGREINFTOP )

assignMaterial( SMATNAME_STIRR, "SHAPE", STIRRUPS )
assignGeometry( SMATNAME_STIRR, "SHAPE", STIRRUPS )



# DEFINE SUPPORTS
createPointSupport( "LEFTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "MIDDLESUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "MIDDLESUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "MIDDLESUPPORT", "TRANSL", [ 1, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "MIDDLESUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "RIGHTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "TRANSL", [ 0, 1, 0] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

COORDLEFTSUPPORT = [ XCOORD[3] , YCOORD[0], 0]
COORDMIDDLESUPPORT = [ XCOORD[11] , YCOORD[0], 0]
COORDRIGHTSUPPORT = [ XCOORD[19] , YCOORD[0], 0]

attach( GEOMETRYSUPPORT, "LEFTSUPPORT", "SHEET83", [COORDLEFTSUPPORT] )
attach( GEOMETRYSUPPORT, "MIDDLESUPPORT", "SHEET85", [COORDMIDDLESUPPORT] )
attach( GEOMETRYSUPPORT, "RIGHTSUPPORT", "SHEET87", [COORDRIGHTSUPPORT] )

createPointSupport( "LOADSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LOADSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LOADSUPPORT", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "LOADSUPPORT", "ROTATI", [ 0, 0, 0 ] )
COORDLOADSUPPORT1 = [ XCOORD[6] , YCOORD[6] , 0 ]
COORDLOADSUPPORT2 = [ XCOORD[16] , YCOORD[6] , 0 ]
attach( GEOMETRYSUPPORT, "LOADSUPPORT", "SHEET79", [COORDLOADSUPPORT1] )
attach( GEOMETRYSUPPORT, "LOADSUPPORT", "SHEET81", [COORDLOADSUPPORT2] )


#DISCRETIZATION METHOD: LOAD CONTROL & DISPLACEMENT CONTROL

#2) DISPLACEMENT CONTROL (attach supports at loading plate)

DISPCOORD1 = [ XCOORD[6], YCOORD[6], 0 ]
DISPCOORD2 = [ XCOORD[16], YCOORD[6], 0 ]
addSet( GEOMETRYLOADSET, "Geometry load case 2" )
rename( GEOMETRYLOADSET, "Geometry load case 2", "Prescribed displacement" )
showView( "GEOM" )
createPointLoad( "Displacement control", "Prescribed displacement" )
setParameter( GEOMETRYLOAD, "Displacement control", "LODTYP", "DEFORM" )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/VALUE", PRESCRIBEDDISPLACEMENT )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/DIRECT", 2 )
attach( GEOMETRYLOAD, "Displacement control", "SHEET79", [DISPCOORD1] )
attach( GEOMETRYLOAD, "Displacement control", "SHEET81", [DISPCOORD2] )



# MESHING 
setElementSize( SHAPELIST, ELEMENTSIZE )
setElementClassType( SHAPELIST, "MEMBRA" )

generateMesh(shapes())

addElementData( "Element data 1" )
setParameter( DATA, "Element data 1", "INTEGR", "HIGH" )
assignElementData( "Element data 1", ELEMENT, SHAPELIST )


# SET UP NON-LINEAR ANALYSIS
analysis = "NLFEA_const_shear_ret(0.01)"
command  = "Structural nonlinear"
addAnalysis( analysis )
addAnalysisCommand( analysis, "NONLIN", command )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/METNAM", "NEWTON" ) 				
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/NEWTON/TYPNAM", "REGULA" )		
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/MAXITE", 40 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/DISPLA", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/TOLCON", 0.01 ) 			
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLCON", 0.001 ) 			
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/SIMULT", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/MAXLS", 10 )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/SIZES", "0.01(100)" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/AMOUNT", "FULL" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/TERMIN", "STEP" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELTYP", "USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/FORCE" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(3)/CRACK/GREEN" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(4)/INCREM/TRANSL/GLOBAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(5)/INCREM/TRANSL/LOCAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(5)/CRKWDT/GREEN/PRINCI" )

EXPORT .DAT- AND .DCF-FILE
exportModel( "masters.dat", 5 )
saveAnalysisCommands( analysis, "masters.dcf")


# RUN ANALYSIS 
runSolver( analysis )
showView( "RESULT" )
setViewPoint( "TOP" )



# FIND LOAD DISPLACEMENT CURVE (LOAD = Support reactions)
DISPCOORD = [XCOORD[6],YCOORD[1], 0 ]    
DISPNODE = findNearestNodes([DISPCOORD])
highlight(NODE,DISPNODE)
DISPNODELIST = [DISPNODE[0]]

FORCENODE1 = findNearestNodes([COORDLEFTSUPPORT]) 
FORCENODE2 = findNearestNodes([COORDMIDDLESUPPORT])
FORCENODE3 = findNearestNodes([COORDRIGHTSUPPORT])
FORCENODES = [FORCENODE1[0],FORCENODE2[0],FORCENODE3[0]]
# FORCENODES = [FORCENODE2[0]]
highlight(NODE,FORCENODES)						

DISPLACEMENTS = []
LASTCASE = len(resultCases(analysis,''))
for i in range(0,LASTCASE):
	DISPLACEMENTS.append(resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Displacements","TDtY"],DISPNODE)[0][1])
	

REACTIONS = []
FORCE = 0
for i in range(0,LASTCASE):
    for j in FORCENODES:
        FORCE = FORCE + resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Reaction Forces","FBY"],(j,))[0][1]
    REACTIONS.append(FORCE)
    FORCE = 0

f = open('LOADDISP.TXT','w')
for i in range(0,len(REACTIONS)):
    f.write('{0:20.6f} {1:20.6f}\n'.format(DISPLACEMENTS[i],REACTIONS[i]))

f.close()

