"""
INPUT FILE FOR NLFEA OF BEAM B1 IN (Kotsovos, M.D. (1982): A fundamental explanation of the
behaviour of reinforced concrete beams in flexure based on the properties of concrete
uncer multiaxial stress. Materials and Structures, 15(90), 529-537).
"""

# OPEN NEW PROJECT
closeProject()
newProject( "NLFEA_Projectwork", 10 )
setModelAnalysisAspects( [ "STRUCT" ] )
setModelDimension( "2D" )
setDefaultMeshOrder( "QUADRATIC" )				
setDefaultMesherType( "HEXQUAD" )				
setUnit( "LENGTH", "MM" )
setUnit( "FORCE", "N" )


# INITIALIZE SHAPE LIST AND SHAPE NUMBERING
SHAPELIST = []
SHAPENUMBER = 1
SELTOL = 0.01

from TOP_FUNC import A_TOP as A_TOP
import os
from math import pi


# SET PARAMETERS
OVERHANG = 100.0
SUPPORTPLATE = 120.0
X1 = 500
LOADPLATE = 200.0
X2 = 112.5
WEBOPENING = 250.0
X3 = 137.5
SUPPORTPLATE2 = 160.0

HEIGHT = 625
WIDTH = 120.0

TOTALLOAD = -337267.0
POINTLOAD = TOTALLOAD/2 						
LOADDISTRIBUTED = TOTALLOAD/LOADPLATE

PRESCRIBEDDISPLACEMENT = -2 					

#Longitudinal Reinforcement
DIAMLONGBOTTOM = 12
DIAMLONGTOP1 = 12
DIAMLONGTOP2 = 10
ASLBOTTOM = ((pi/4)*DIAMLONGBOTTOM**2)*4
ASLTOP1 = ((pi/4)*DIAMLONGTOP1**2)*4
ASLTOP2 = ((pi/4)*DIAMLONGTOP2**2)*2
#Web Reinforcement
DIAMHORIZONTAL = 8
DIAMVERTICAL = 8
ASHORIZONTAL = ((pi/4)*DIAMHORIZONTAL**2)*2
ASVERTICAL = ((pi/4)*DIAMVERTICAL**2)
COVER = 25 										
SPACING = 200 									

ELEMENTSIZE = HEIGHT/12					 			


YOUNGSMOD = 25000								
POISSONRATIO = 0.15 							
POISSONRATIO_STEEL = 0.3 						
FC = 25.3 										
FCT = 2.01										
Fck= 17.3 										
GF = 0.1306 									
GC = 32.6456 									
BETA = 0.1										
FY_12 = 510.0
FY_10 = 590.0
FY_8 = 400.0
FY_Steel_Plate = 355

ES_BOTTOM = 201000.0
ES_TOP1 = 201000.0
ES_TOP2 = 194000.0
ES_WEB_HOR = 195000.0
ES_WEB_VERT = 195000.0
ES_STEELPLATE = 200000
EHTOT = 4000.0  								
EPSMAX = 0.1   						

# ESTABLISH LISTS WITH COORDINATES
XCOORD = [0]
XCOORD.append(XCOORD[0]+OVERHANG)
XCOORD.append(XCOORD[1]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[2]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[3]+X1)
XCOORD.append(XCOORD[4]+LOADPLATE)
XCOORD.append(XCOORD[5]+X2)
XCOORD.append(XCOORD[6]+WEBOPENING)
XCOORD.append(XCOORD[7]+X3)
XCOORD.append(XCOORD[8]+SUPPORTPLATE2/2)
XCOORD.append(XCOORD[9]+SUPPORTPLATE2/2)
XCOORD.append(XCOORD[10]+X3)
XCOORD.append(XCOORD[11]+WEBOPENING)
XCOORD.append(XCOORD[12]+X2)
XCOORD.append(XCOORD[13]+LOADPLATE)
XCOORD.append(XCOORD[14]+X1)
XCOORD.append(XCOORD[15]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[16]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[17]+OVERHANG)

YCOORD = [0]
YCOORD.append(YCOORD[0]+(HEIGHT-WEBOPENING)/2)
YCOORD.append(YCOORD[1]+WEBOPENING)
YCOORD.append(YCOORD[2]+(HEIGHT-WEBOPENING)/2)

#ESTABLiSH MIDSPAN-COORDINATE
XMIDSPANCOORD =[0]
XMIDSPANCOORD.append(XMIDSPANCOORD[0] + 830)

#ESTABLISH LIST WITH COORDINATES FOR SUPPORT PLATE 
XSUPPORTCOORD = [0]
XSUPPORTCOORD.append(XSUPPORTCOORD[0]+OVERHANG)
XSUPPORTCOORD.append(XSUPPORTCOORD[1]+SUPPORTPLATE/2)
XSUPPORTCOORD.append(XSUPPORTCOORD[2]+SUPPORTPLATE/2)
XSUPPORTCOORD.append(XSUPPORTCOORD[3]+X1)
XSUPPORTCOORD.append(XSUPPORTCOORD[4]+LOADPLATE)
XSUPPORTCOORD.append(XSUPPORTCOORD[5]+X2)
XSUPPORTCOORD.append(XSUPPORTCOORD[6]+WEBOPENING)
XSUPPORTCOORD.append(XSUPPORTCOORD[7]+X3)
XSUPPORTCOORD.append(XSUPPORTCOORD[8]+SUPPORTPLATE2/2)
XSUPPORTCOORD.append(XSUPPORTCOORD[9]+SUPPORTPLATE2/2)
XSUPPORTCOORD.append(XSUPPORTCOORD[10]+X3)
XSUPPORTCOORD.append(XSUPPORTCOORD[11]+WEBOPENING)
XSUPPORTCOORD.append(XSUPPORTCOORD[12]+X2)
XSUPPORTCOORD.append(XSUPPORTCOORD[13]+LOADPLATE)
XSUPPORTCOORD.append(XSUPPORTCOORD[14]+X1)
XSUPPORTCOORD.append(XSUPPORTCOORD[15]+SUPPORTPLATE/2)
XSUPPORTCOORD.append(XSUPPORTCOORD[16]+SUPPORTPLATE/2)
XSUPPORTCOORD.append(XSUPPORTCOORD[17]+OVERHANG)

YSUPPORTCOORD = [0]
YSUPPORTCOORD.append(YSUPPORTCOORD[0]-45) 

#ESTABLISH LIST WITH COORDINATES FOR LOAD PLATE 
XLOADCOORD = [0]
XLOADCOORD.append(XLOADCOORD[0]+OVERHANG)
XLOADCOORD.append(XLOADCOORD[1]+SUPPORTPLATE)
XLOADCOORD.append(XLOADCOORD[2]+X1)
XLOADCOORD.append(XLOADCOORD[3]+LOADPLATE/2) 
XLOADCOORD.append(XLOADCOORD[4]+LOADPLATE/2) 
XLOADCOORD.append(XLOADCOORD[5]+X2)
XLOADCOORD.append(XLOADCOORD[6]+WEBOPENING)
XLOADCOORD.append(XLOADCOORD[7]+X3)
XLOADCOORD.append(XLOADCOORD[8]+SUPPORTPLATE2)
XLOADCOORD.append(XLOADCOORD[9]+X3)
XLOADCOORD.append(XLOADCOORD[10]+WEBOPENING)
XLOADCOORD.append(XLOADCOORD[11]+X2)
XLOADCOORD.append(XLOADCOORD[12]+LOADPLATE/2)
XLOADCOORD.append(XLOADCOORD[13]+LOADPLATE/2) 
XLOADCOORD.append(XLOADCOORD[14]+X1)
XLOADCOORD.append(XLOADCOORD[15]+SUPPORTPLATE)
XLOADCOORD.append(XLOADCOORD[16]+OVERHANG)

YLOADCOORD = [0]
YLOADCOORD.append(YLOADCOORD[0]+(HEIGHT-WEBOPENING)/2)
YLOADCOORD.append(YLOADCOORD[1]+WEBOPENING)
YLOADCOORD.append(YLOADCOORD[2]+(HEIGHT-WEBOPENING)/2)
YLOADCOORD.append(YLOADCOORD[3]+45) #Loadingplates

# CREATE GEOMETRY
SHAPENUMBER = 1
SHAPELIST = []
SHAPENUMBER,SHAPELIST = A_TOP(1,1,18,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,2,6,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(8,2,4,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(13,2,6,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,3,18,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(2,1,2,1,SHAPENUMBER,SHAPELIST,XSUPPORTCOORD,YSUPPORTCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(9,1,2,1,SHAPENUMBER,SHAPELIST,XSUPPORTCOORD,YSUPPORTCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(16,1,2,1,SHAPENUMBER,SHAPELIST,XSUPPORTCOORD,YSUPPORTCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(4,4,2,1,SHAPENUMBER,SHAPELIST,XLOADCOORD,YLOADCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(13,4,2,1,SHAPENUMBER,SHAPELIST,XLOADCOORD,YLOADCOORD,createSheet)
fitAll()

# LONGITUDINAL REINFORCEMENT
P1 = [XCOORD[0],COVER,0]
P2 = [XCOORD[18],COVER,0]
createLine( 'LONGREINFBOTTOM',  P1, P2 )
P1 = [XCOORD[0],YCOORD[3]-COVER,0]
P2 = [XCOORD[18],YCOORD[3]-COVER,0]
createLine( 'LONGREINFTOP1',  P1, P2 )
P1 = [XCOORD[0]+600,YCOORD[3]-COVER,0]
P2 = [XCOORD[18]-600,YCOORD[3]-COVER,0]
createLine( 'LONGREINFTOP2',  P1, P2 )

LONGREINFBOTTOM = ['LONGREINFBOTTOM']
LONGREINFTOP1 = ['LONGREINFTOP1']
LONGREINFTOP2 = ['LONGREINFTOP2']

# HORIZONTAL WEB REINFORCEMENT
EXTRA_COVER = 177.5  
S1 = [XCOORD[0]+COVER,COVER + EXTRA_COVER,0]
S2 = [XCOORD[6],COVER+EXTRA_COVER,0]
createLine( 'HOR_WEB11',  S1, S2 )
S1 = [XCOORD[7],COVER + EXTRA_COVER,0]
S2 = [XCOORD[11],COVER+EXTRA_COVER,0]
createLine( 'HOR_WEB12',  S1, S2 )
S1 = [XCOORD[12],COVER + EXTRA_COVER,0]
S2 = [XCOORD[18]-COVER,COVER+EXTRA_COVER,0]
createLine( 'HOR_WEB13',  S1, S2 )
S1 = [XCOORD[0]+COVER,YCOORD[3]-COVER-EXTRA_COVER,0]
S2 = [XCOORD[6],YCOORD[3]-COVER-EXTRA_COVER,0]
createLine( 'HOR_WEB21',  S1, S2 )
S1 = [XCOORD[7],YCOORD[3]-COVER-EXTRA_COVER,0]
S2 = [XCOORD[11],YCOORD[3]-COVER-EXTRA_COVER,0]
createLine( 'HOR_WEB22',  S1, S2 )
S1 = [XCOORD[12],YCOORD[3]-COVER-EXTRA_COVER,0]
S2 = [XCOORD[18]-COVER,YCOORD[3]-COVER-EXTRA_COVER,0]
createLine( 'HOR_WEB23',  S1, S2 )

HOR_WEB1 = ['HOR_WEB11', 'HOR_WEB12', 'HOR_WEB13' ]
HOR_WEB2 = ['HOR_WEB21', 'HOR_WEB22', 'HOR_WEB23']
 
# VERTICAL WEB REINFORCEMENT
WEB_VERT = [OVERHANG]
AS_WEB_VERT = []
for i in range(1,15):
   WEB_VERT.append(WEB_VERT[i-1]+SPACING)

SNUM = 1
for i in range(0,len(WEB_VERT)):

   if WEB_VERT[i] == OVERHANG + 5*SPACING or WEB_VERT[i] == OVERHANG + 9*SPACING:
      P1 = [WEB_VERT[i],YCOORD[0]+COVER,0]
      P2 = [WEB_VERT[i],YCOORD[1],0]
      P3 = [WEB_VERT[i],YCOORD[2],0]
      P4 = [WEB_VERT[i],YCOORD[3]-COVER,0]
      LINENAME = 'STIRRUP{}'.format(SNUM)
      LINENAME2 = 'STIRRUP{}'.format(SNUM+1)
      createLine( LINENAME,  P1, P2 )
      createLine( LINENAME2,  P3, P4 )
      AS_WEB_VERT.append(LINENAME)
      AS_WEB_VERT.append(LINENAME2)
      SNUM = SNUM + 2
   
   else:
      P1 = [WEB_VERT[i], YCOORD[0]+COVER, 0]
      P2 = [WEB_VERT[i], YCOORD[3]-COVER, 0]
      LINENAME = 'STIRRUP{}'.format(SNUM)
      createLine( LINENAME,  P1, P2 )
      AS_WEB_VERT.append(LINENAME)
      SNUM = SNUM + 1

# DEFINE PROPERTIES FOR THE CONCRETE GEOMETRY AND MATERIAL
# TOTAL STRAIN FIXED CRACKING
addMaterial( "Concrete", "CONCR", "TSCR", [] )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/YOUNG", YOUNGSMOD )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/POISON", POISSONRATIO )

setParameter( MATERIAL, "Concrete", "MODTYP/TOTCRK", "FIXED" )			

setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "PARABO" )			
setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", FC )
setParameter( MATERIAL, "Concrete", "COMPRS/GC", GC )
setParameter( MATERIAL, "Concrete", "COMPRS/CONFIN/CNFCRV", "VECCHI" )
setParameter( MATERIAL, "Concrete", "COMPRS/REDUCT/REDCRV", "VC1993" )

setParameter( MATERIAL, "Concrete", "TENSIL/TENCRV", "MC2010" )			
setParameter( MATERIAL, "Concrete", "TENSIL/TENSTR", FCT )
setParameter( MATERIAL, "Concrete", "TENSIL/GF1", GF ) 
setParameter( MATERIAL, "Concrete", "TENSIL/POISRE/POIRED", "DAMAGE" )

setParameter( MATERIAL, "Concrete", "SHEAR/SHRCRV", "DAMAGE" )
# setParameter( MATERIAL, "Concrete", "SHEAR/SHRCRV", "CONSTA" )
# setParameter( MATERIAL, "Concrete", "SHEAR/BETA", BETA )    			

CONMATNAME = "Concrete"
addGeometry( CONMATNAME, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, CONMATNAME, "THICK", WIDTH )

assignMaterial( CONMATNAME, "SHAPE", SHAPELIST[0:52] )
assignGeometry( CONMATNAME, "SHAPE", SHAPELIST[0:52] )

# DEFINE PROPERTIES FOR THE STEEL GEOMETRY AND MATERIAL
# TOTAL STRAIN FIXED CRACKING
addMaterial( "Steelplate", "MCSTEL", "TRESCA", [] )
setParameter( MATERIAL, "Steelplate", "TREPLA/YIELD", "VMISES" )
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/YOUNG", ES_STEELPLATE )
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/POISON", POISSONRATIO_STEEL )
setParameter( MATERIAL, "Steelplate", "TREPLA/YLDSTR", FY_Steel_Plate )

CONMATNAME = "Steelplate"
addGeometry( CONMATNAME, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, CONMATNAME, "THICK", WIDTH )

assignMaterial( CONMATNAME, "SHAPE", SHAPELIST[52:62] )
assignGeometry( CONMATNAME, "SHAPE", SHAPELIST[52:62] )

# DEFINE PROPERTIES FOR THE REINFORCEMENT GEOMETRY AND MATERIAL
setReinforcementAspects( LONGREINFBOTTOM )
setReinforcementAspects( LONGREINFTOP1 )
setReinforcementAspects( LONGREINFTOP2 )
setReinforcementAspects( HOR_WEB1 )
setReinforcementAspects( HOR_WEB2 )
setReinforcementAspects( AS_WEB_VERT )
RMATNAME_BOTTOM = "Bottom Steel reinforcement"
RMATNAME_TOP1 = "Top1 Steel reinforcement"
RMATNAME_TOP2 = "Top2 Steel reinforcement"
SMATNAME_HOR = "Horizontal Stirrups"
SMATNAME_VERT = "Vertical Stirrups"

#SMAX AND EPSPLMAX ARE THE PARAMETERS FOR THE LINEAR HARDENING RELATION BETWEEN YIELD STRESS AND PLASTIC STRAIN

SMAX_BOTTOM = FY_12 + EHTOT*(EPSMAX - FY_12/ES_BOTTOM)
EPSPLMAX_BOTTOM = EPSMAX*(1-EHTOT/ES_BOTTOM) + FY_12/ES_BOTTOM*(EHTOT/ES_BOTTOM - 1)
SMAX_TOP1 = FY_12 + EHTOT*(EPSMAX - FY_12/ES_TOP1)
EPSPLMAX_TOP1 = EPSMAX*(1-EHTOT/ES_TOP1) + FY_12/ES_TOP1*(EHTOT/ES_TOP1 - 1)
SMAX_TOP2 = FY_10 + EHTOT*(EPSMAX - FY_10/ES_TOP2)
EPSPLMAX_TOP2 = EPSMAX*(1-EHTOT/ES_TOP2) + FY_10/ES_TOP2*(EHTOT/ES_TOP2 - 1)
SMAX_WEB_HOR = FY_8 + EHTOT*(EPSMAX - FY_8/ES_WEB_HOR)
EPSPLMAX_WEB_HOR = EPSMAX*(1-EHTOT/ES_WEB_HOR) + FY_8/ES_WEB_HOR*(EHTOT/ES_WEB_HOR - 1)
SMAX_WEB_VERT = FY_8 + EHTOT*(EPSMAX - FY_8/ES_WEB_VERT)
EPSPLMAX_WEB_VERT = EPSMAX*(1-EHTOT/ES_WEB_VERT) + FY_8/ES_WEB_VERT*(EHTOT/ES_WEB_VERT - 1)

addMaterial( RMATNAME_BOTTOM, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_BOTTOM, "LINEAR/ELASTI/YOUNG", ES_BOTTOM )
setParameter( MATERIAL, RMATNAME_BOTTOM, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_BOTTOM, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, RMATNAME_BOTTOM, "PLASTI/HARDI2/KAPSIG", [ 0, FY_12, EPSPLMAX_BOTTOM, SMAX_BOTTOM ] )

addMaterial( RMATNAME_TOP1, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_TOP1, "LINEAR/ELASTI/YOUNG", ES_TOP1 )
setParameter( MATERIAL, RMATNAME_TOP1, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_TOP1, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, RMATNAME_TOP1, "PLASTI/HARDI2/KAPSIG", [ 0, FY_12, EPSPLMAX_TOP1, SMAX_TOP1 ] )

addMaterial( RMATNAME_TOP2, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_TOP2, "LINEAR/ELASTI/YOUNG", ES_TOP2 )
setParameter( MATERIAL, RMATNAME_TOP2, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_TOP2, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, RMATNAME_TOP2, "PLASTI/HARDI2/KAPSIG", [ 0, FY_10, EPSPLMAX_TOP2, SMAX_TOP2 ] )

addMaterial( SMATNAME_HOR, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_HOR, "LINEAR/ELASTI/YOUNG", ES_WEB_HOR )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/HARDI2/KAPSIG", [ 0, FY_8, EPSPLMAX_WEB_HOR, SMAX_WEB_HOR ] )

addMaterial( SMATNAME_VERT, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_VERT, "LINEAR/ELASTI/YOUNG", ES_WEB_VERT )
setParameter( MATERIAL, SMATNAME_VERT, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_VERT, "PLASTI/HARDI2/KAPSIG", [] )
setParameter( MATERIAL, SMATNAME_VERT, "PLASTI/HARDI2/KAPSIG", [ 0, FY_8, EPSPLMAX_WEB_VERT, SMAX_WEB_VERT ] )


addGeometry( RMATNAME_BOTTOM, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_BOTTOM, "CROSSE", ASLBOTTOM )

addGeometry( RMATNAME_TOP1, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_TOP1, "CROSSE", ASLTOP1 )

addGeometry( RMATNAME_TOP2, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_TOP2, "CROSSE", ASLTOP2 )

addGeometry( SMATNAME_HOR, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_HOR, "CROSSE", ASHORIZONTAL )

addGeometry( SMATNAME_VERT, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_VERT, "CROSSE", ASVERTICAL )

assignMaterial( RMATNAME_BOTTOM, "SHAPE", LONGREINFBOTTOM )
assignGeometry( RMATNAME_BOTTOM, "SHAPE", LONGREINFBOTTOM )

assignMaterial( RMATNAME_TOP1, "SHAPE", LONGREINFTOP1 )
assignGeometry( RMATNAME_TOP1, "SHAPE", LONGREINFTOP1 )

assignMaterial( RMATNAME_TOP2, "SHAPE", LONGREINFTOP2 )
assignGeometry( RMATNAME_TOP2, "SHAPE", LONGREINFTOP2 )

assignMaterial( SMATNAME_HOR, "SHAPE", HOR_WEB1 )
assignGeometry( SMATNAME_HOR, "SHAPE", HOR_WEB1 )

assignMaterial( SMATNAME_HOR, "SHAPE", HOR_WEB2 )
assignGeometry( SMATNAME_HOR, "SHAPE", HOR_WEB2 )

assignMaterial( SMATNAME_VERT, "SHAPE", AS_WEB_VERT )
assignGeometry( SMATNAME_VERT, "SHAPE", AS_WEB_VERT )

# DEFINE SUPPORTS
createPointSupport( "LEFTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "TRANSL", [ 1, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "MIDDLESUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "MIDDLESUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "MIDDLESUPPORT", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "MIDDLESUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "RIGHTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "TRANSL", [ 0, 1, 0] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "LOADSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LOADSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LOADSUPPORT", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "LOADSUPPORT", "ROTATI", [ 0, 0, 0 ] )


COORDLEFTSUPPORT = [ XSUPPORTCOORD[2] , YSUPPORTCOORD[1], 0]
COORDMIDDLESUPPORT = [ XSUPPORTCOORD[9] , YSUPPORTCOORD[1], 0]
COORDRIGHTSUPPORT = [ XSUPPORTCOORD[16] , YSUPPORTCOORD[1] , 0 ]
COORDLOADSUPPORT1 = [ XLOADCOORD[4] , YLOADCOORD[4] , 0 ]
COORDLOADSUPPORT2 = [ XLOADCOORD[12] , YLOADCOORD[4] , 0 ]

attach( GEOMETRYSUPPORT, "LEFTSUPPORT", SHAPELIST[53], [COORDLEFTSUPPORT] )
attach( GEOMETRYSUPPORT, "MIDDLESUPPORT", SHAPELIST[55], [COORDMIDDLESUPPORT] )
attach( GEOMETRYSUPPORT, "RIGHTSUPPORT", SHAPELIST[57], [COORDRIGHTSUPPORT] )
attach( GEOMETRYSUPPORT, "LOADSUPPORT", SHAPELIST[59], [COORDLOADSUPPORT1] )
attach( GEOMETRYSUPPORT, "LOADSUPPORT", SHAPELIST[61], [COORDLOADSUPPORT2] )


#DISCRETIZATION METHOD: LOAD CONTROL & DISPLACEMENT CONTROL

#2) DISPLACEMENT CONTROL (attach supports at loading plate)
addSet( GEOMETRYLOADSET, "Geometry load case 2" )
showView( "GEOM" )
createPointLoad( "Displacement control", "Geometry load case 2" )
setParameter( GEOMETRYLOAD, "Displacement control", "LODTYP", "DEFORM" )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/VALUE", PRESCRIBEDDISPLACEMENT )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/DIRECT", 2 )
attach( GEOMETRYLOAD, "Displacement control", "SHEET59", [[ XLOADCOORD[4], YLOADCOORD[4], 0 ]] )
attach( GEOMETRYLOAD, "Displacement control", "SHEET61", [[ XLOADCOORD[13], YLOADCOORD[4], 0 ]] )


# MESHING 
setElementSize( SHAPELIST, ELEMENTSIZE )
setElementClassType( SHAPELIST, "MEMBRA" )

generateMesh(shapes())

addElementData( "Element data 1" )
setParameter( DATA, "Element data 1", "INTEGR", "HIGH" )
assignElementData( "Element data 1", ELEMENT, SHAPELIST )


# SET UP NON-LINEAR ANALYSIS
analysis = "NLFEA_Prosjoppg_masterparameters"
command  = "Structural nonlinear"
addAnalysis( analysis )
addAnalysisCommand( analysis, "NONLIN", command )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/METNAM", "NEWTON" ) 				
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/NEWTON/TYPNAM", "REGULA" )		
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/MAXITE", 40 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/DISPLA", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/TOLCON", 0.01 ) 			
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLCON", 0.001 ) 			
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/SIMULT", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/MAXLS", 10 )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/SIZES", "0.01(100)" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/AMOUNT", "FULL" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/TERMIN", "STEP" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELTYP", "USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/FORCE" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(3)/CRACK/GREEN" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(4)/INCREM/TRANSL/GLOBAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(5)/INCREM/TRANSL/LOCAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(5)/CRKWDT/GREEN/PRINCI" )


EXPORT .DAT- AND .DCF-FILE
exportModel( "projectwork.dat", 5 )
saveAnalysisCommands( analysis, "projectwork.dcf")


# RUN ANALYSIS
runSolver( analysis )
showView( "RESULT" )
setViewPoint( "TOP" )




# FIND LOAD DISPLACEMENT CURVE (LOAD = Support reactions)
DISPCOORD = [XMIDSPANCOORD[1],YCOORD[0], 0 ]    
DISPNODE = findNearestNodes([DISPCOORD])
highlight(NODE,DISPNODE)
DISPNODELIST = [DISPNODE[0]]

FORCENODE1 = findNearestNodes([COORDLEFTSUPPORT]) 
FORCENODE2 = findNearestNodes([COORDMIDDLESUPPORT])
FORCENODE3 = findNearestNodes([COORDRIGHTSUPPORT])
FORCENODES = [FORCENODE1[0],FORCENODE2[0],FORCENODE3[0]]
highlight(NODE,FORCENODES)						

DISPLACEMENTS = []
LASTCASE = len(resultCases(analysis,''))
for i in range(0,LASTCASE):
    DISPLACEMENTS.append(resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Displacements","TDtY"],DISPNODE)[0][1])
	
REACTIONS = []
FORCE = 0
for i in range(0,LASTCASE):
    for j in FORCENODES:
        FORCE = FORCE + resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Reaction Forces","FBY"],(j,))[0][1]
    REACTIONS.append(FORCE)
    FORCE = 0

f = open('LOADDISP.TXT','w')
for i in range(0,len(REACTIONS)):
    f.write('{0:20.6f} {1:20.6f}\n'.format(DISPLACEMENTS[i],REACTIONS[i]))

f.close()
