# OPEN NEW PROJECT
closeProject()
newProject( "CONCRETE_BEAM", 10 )
setModelAnalysisAspects( [ "STRUCT" ] )
setModelDimension( "2D" )
setDefaultMeshOrder( "QUADRATIC" ) 
setDefaultMesherType( "HEXQUAD" )
setUnit( "LENGTH", "MM" )
setUnit( "FORCE", "N" )

# INITIALIZE SHAPE LIST AND SHAPE NUMBERING
SHAPELIST = []
SHAPENUMBER = 1
SELTOL = 0.01

from TOP_FUNC import A_TOP as A_TOP
import os
from math import pi

# SET PARAMETERS
OVERHANG = 100.0
SUPPORTPLATE = 120.0
SUPPORTPLATE2 = 160.0
LOADDIST1 = 500.0
LOADPLATE = 200.0
DISTLOADOP = 175.0 #distance from loadplate to web opening 
WEBOPENING = 125.0 # width if web opening
X1 = 200.0 #horizontal distance from web opening to mid-support 
Y1 = 250.0 #distance from bottom of the beam to web opening
HEIGHT = 625.0 #of the beam
WIDTH = 120.0 #of the beam
PRESCRIBEDDISPLACEMENT = -3 
ELEMENTSIZE =HEIGHT/12 

#Longitudinal Reinforcement
DIAMLONG1 = 12
DIAMLONG2 = 10 
ASLTOP1 = 4*(pi/4*DIAMLONG1**2) 
ASLTOP2 = 2*(pi/4*DIAMLONG2**2)  
ASLBOTTOM = 4*(pi/4*DIAMLONG1**2) 

#WEB REINFORCEMENT
DIAMSTIRR = 8.0
ASSHOR = 2*(pi/4*DIAMSTIRR**2) 
ASSVERT = 2*(pi/4*DIAMSTIRR**2) 
COVER = 25.0
SPACING = 200.0 
SPACINGVERT = 200.0
TOPREINF = 600.0 

#MATERIAL PARAMETERS
YOUNGSMOD = 29525 
POISSONRATIO = 0.15
POISSONRATIO_STEEL = 0.3
FCT = 2.068 #tensile strength of concrete
FC = 26.1 #mean compressive strength of concrete 
GF = 0.1313 #fracture energy
GC = 32.829 #compressive fracture energy  
BETA = 0.10 
FY_12 = 510.0
FY_10 = 590.0
FY_8 = 400.0
FY_steelplate = 355.0

ESLONG1 = 201000.0
ESLONG2 = 194000.0
ESWEB_VERT = 195000.0
ESWEB_HOR = 195000.0
ESWEB = 195000.0 
E_steelplate = 210000.0
EHTOT1 = 0.02*ESLONG1 #hardening modulus of reinforcement
EHTOT2 = 0.02*ESLONG2
EHTOT3=0.02*ESWEB

EPSMAX = 0.1 #max total strain of reinforcement

# ESTABLISH LISTS WITH COORDINATES
XCOORD = [0]
XCOORD.append(XCOORD[0]+OVERHANG)
XCOORD.append(XCOORD[1]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[2]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[3]+LOADDIST1)
XCOORD.append(XCOORD[4]+LOADPLATE/2)
XCOORD.append(XCOORD[5]+LOADPLATE/2)
XCOORD.append(XCOORD[6]+DISTLOADOP)
XCOORD.append(XCOORD[7]+WEBOPENING)
XCOORD.append(XCOORD[8]+X1)
XCOORD.append(XCOORD[9]+SUPPORTPLATE2/2)
XCOORD.append(XCOORD[10]+SUPPORTPLATE2/2)
XCOORD.append(XCOORD[11]+X1)
XCOORD.append(XCOORD[12]+WEBOPENING)
XCOORD.append(XCOORD[13]+DISTLOADOP)
XCOORD.append(XCOORD[14]+LOADPLATE/2)
XCOORD.append(XCOORD[15]+LOADPLATE/2)
XCOORD.append(XCOORD[16]+LOADDIST1)
XCOORD.append(XCOORD[17]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[18]+SUPPORTPLATE/2)
XCOORD.append(XCOORD[19]+OVERHANG)

YCOORD = [0]
YCOORD.append(YCOORD[0]+45)
YCOORD.append(YCOORD[1]+Y1)
YCOORD.append(YCOORD[2]+WEBOPENING)
YCOORD.append(YCOORD[3]+Y1)
YCOORD.append(YCOORD[4]+45)

# CREATE GEOMETRY
SHAPENUMBER = 1
SHAPELIST = []
SHAPENUMBER,SHAPELIST = A_TOP(1,2,20,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,3,7,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(9,3,4,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(14,3,7,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(1,4,20,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(2,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(5,5,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(10,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(15,5,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
SHAPENUMBER,SHAPELIST = A_TOP(18,1,2,1,SHAPENUMBER,SHAPELIST,XCOORD,YCOORD,createSheet)
fitAll()

# LONGITUDINAL REINFORCEMENT
P1 = [XCOORD[0]+COVER,YCOORD[4]-COVER,0]
P2 = [XCOORD[20]-COVER,YCOORD[4]-COVER,0]
createLine( 'LONGREINFTOP1',  P1, P2 )
P1 = [XCOORD[0]+TOPREINF,YCOORD[4]-COVER,0] # 
P2 = [XCOORD[20]-TOPREINF,YCOORD[4]-COVER,0]
createLine( 'LONGREINFTOP2',  P1, P2 )
P1 = [XCOORD[0]+COVER,YCOORD[1]+ COVER,0] # 
P2 = [XCOORD[20]-COVER,YCOORD[1]+COVER,0]
createLine( 'LONGREINFBOTTOM',  P1, P2 )

LONGREINFTOP1 = ['LONGREINFTOP1']
LONGREINFTOP2 = ['LONGREINFTOP2']
LONGREINFBOTTOM = ['LONGREINFBOTTOM']

# HORIZONTAL WEB REINFORCEMENT
S1 = [XCOORD[0]+COVER,YCOORD[1]+HEIGHT/2 +100,0]
S2 = [XCOORD[20]-COVER,YCOORD[1]+HEIGHT/2 +100,0]
createLine( 'HOR_WEB1',  S1, S2 )
S1 = [XCOORD[0]+COVER,YCOORD[1]+HEIGHT/2 -100,0]
S2 = [XCOORD[20]-COVER,YCOORD[1]+HEIGHT/2 -100,0]
createLine( 'HOR_WEB2',  S1, S2 )

HOR_WEB1 = ['HOR_WEB1']
HOR_WEB2 = ['HOR_WEB2']

# VERTICAL STIRRUPS
XSTIRR = [-OVERHANG]
ASSTIRR_VERT = []
for i in range(1,16):
   XSTIRR.append(XSTIRR[i-1]+SPACINGVERT)
SNUM = 1   
for i in range(1,len(XSTIRR)):

   if XSTIRR[i] == OVERHANG + 5*SPACINGVERT or XSTIRR[i] == OVERHANG + 9*SPACINGVERT:
	   P1 = [XSTIRR[i], YCOORD[1]+COVER,0]
	   P2 = [XSTIRR[i], YCOORD[2],0]
	   P3 = [XSTIRR[i], YCOORD[3],0]
	   P4 = [XSTIRR[i], YCOORD[4]-COVER,0]
	   LINENAME = 'STIRRUP{}'.format(SNUM)
	   LINENAME2 = 'STIRRUP{}'.format(SNUM+1)
	   createLine( LINENAME,  P1, P2 )
	   createLine( LINENAME2,  P3, P4 )
	   ASSTIRR_VERT.append(LINENAME)
	   ASSTIRR_VERT.append(LINENAME2)
	   SNUM = SNUM + 2
   else:
	   P1 = [XSTIRR[i], YCOORD[1]+COVER,0]
	   P2 = [XSTIRR[i], YCOORD[4]-COVER,0]
	   LINENAME = 'STIRRUP{}'.format(SNUM)
	   createLine( LINENAME,  P1, P2 )
	   ASSTIRR_VERT.append(LINENAME)
	   SNUM = SNUM + 1

# DEFINE PROPERTIES FOR THE CONCRETE GEOMETRY AND MATERIAL
addMaterial( "Concrete", "CONCR", "TSCR", [] )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/YOUNG", YOUNGSMOD )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/POISON", POISSONRATIO )
setParameter( MATERIAL, "Concrete", "MODTYP/TOTCRK", "FIXED" ) 
setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "PARABO" ) 

setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", FC )
setParameter( MATERIAL, "Concrete", "COMPRS/GC", GC )
setParameter( MATERIAL, "Concrete", "COMPRS/CONFIN/CNFCRV", "VECCHI" )  
setParameter( MATERIAL, "Concrete", "COMPRS/REDUCT/REDCRV", "VC1993" )

setParameter( MATERIAL, "Concrete", "TENSIL/TENCRV", "MC2010" ) 
setParameter( MATERIAL, "Concrete", "TENSIL/TENSTR", FCT )
setParameter( MATERIAL, "Concrete", "TENSIL/GF1", GF )
setParameter( MATERIAL, "Concrete", "TENSIL/POISRE/POIRED", "DAMAGE" )

setParameter( MATERIAL, "Concrete", "SHEAR/SHRCRV", "DAMAGE" ) 
#setParameter( MATERIAL, "Concrete", "SHEAR/BETA", BETA )   

CONMATNAME = "Concrete"
addGeometry( CONMATNAME, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, CONMATNAME, "THICK", WIDTH )
assignMaterial( CONMATNAME, "SHAPE", SHAPELIST[0:58] )
assignGeometry( CONMATNAME, "SHAPE", SHAPELIST[0:58] )   

#DEFINE PROPERTIES FOR THE STEEL GEOMETRY AND MATERIAL IN THE SUPPORT PLATES
addMaterial( "Steelplate", "MCSTEL", "TRESCA", [] )
setParameter( MATERIAL, "Steelplate", "TREPLA/YIELD", "VMISES" )
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/YOUNG", E_steelplate)  
setParameter( MATERIAL, "Steelplate", "LINEAR/ELASTI/POISON", POISSONRATIO_STEEL )
setParameter( MATERIAL, "Steelplate", "TREPLA/YLDSTR", FY_steelplate )
 
RMATNAME_STEELPLATE = "Steelplate"
addGeometry( RMATNAME_STEELPLATE, "SHEET", "MEMBRA", [] )
setParameter( GEOMET, RMATNAME_STEELPLATE, "THICK", WIDTH )

# ASSIGN MATERIAL FOR STEEL PLATES 
assignMaterial( RMATNAME_STEELPLATE, "SHAPE", SHAPELIST[58:68] )
assignGeometry( RMATNAME_STEELPLATE, "SHAPE", SHAPELIST[58:68] )

# DEFINE PROPERTIES FOR THE REINFORCEMENT GEOMETRY AND MATERIAL
setReinforcementAspects( LONGREINFTOP1 )
setReinforcementAspects( LONGREINFTOP2 )
setReinforcementAspects( LONGREINFBOTTOM )
setReinforcementAspects( HOR_WEB1 )
setReinforcementAspects( HOR_WEB2 )
setReinforcementAspects( ASSTIRR_VERT )
RMATNAME_BOTTOM = "Bottom Steel reinforcement"
RMATNAME_TOP1 = "Top1 Steel reinforcement"
RMATNAME_TOP2 = "Top2 Steel reinforcement"
SMATNAME_HOR = "Horizontal Stirrups"
SMATNAME_VERT = "Vertical Stirrups"

#SMAX AND EPSPLMAX ARE THE PARAMETERS FOR THE LINEAR HARDENING RELATION BETWEEN YIELD STRESS AND PLASTIC STRAIN
SMAX_TOP1 = FY_12 + EHTOT1*(EPSMAX - FY_12/ESLONG1) 
SMAX_TOP2 = FY_10 + EHTOT2*(EPSMAX - FY_10/ESLONG2)
SMAX_BOTTOM = FY_12+ EHTOT1*(EPSMAX - FY_12/ESLONG1)
EPSPLMAX1 = EPSMAX*(1-EHTOT1/ESLONG1) + FY_12/ESLONG1*(EHTOT1/ESLONG1 - 1)
EPSPLMAX2 = EPSMAX*(1-EHTOT2/ESLONG2) + FY_10/ESLONG2*(EHTOT2/ESLONG2 - 1)
EPSPLMAX3 = EPSMAX*(1-EHTOT1/ESLONG1) + FY_12/ESLONG1*(EHTOT1/ESLONG1 - 1)
SMAX_WEB_HOR = FY_8 + EHTOT3*(EPSMAX - FY_8/ESWEB_HOR)
EPSPLMAX_WEB_HOR = EPSMAX*(1-EHTOT3/ESWEB_HOR) + FY_8/ESWEB_HOR*(EHTOT3/ESWEB_HOR - 1)
SMAX_WEB_VERT = FY_8 + EHTOT3*(EPSMAX - FY_8/ESWEB_VERT)
EPSPLMAX_WEB_VERT = EPSMAX*(1-EHTOT3/ESWEB_VERT) + FY_8/ESWEB_VERT*(EHTOT3/ESWEB_VERT - 1)
	
addMaterial( RMATNAME_TOP1, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_TOP1, "LINEAR/ELASTI/YOUNG", ESLONG1 )
setParameter( MATERIAL, RMATNAME_TOP1, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_TOP1, "PLASTI/HARDI2/KAPSIG", [ 0, FY_12, EPSPLMAX1, SMAX_TOP1 ] )

addMaterial( RMATNAME_TOP2, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_TOP2, "LINEAR/ELASTI/YOUNG", ESLONG2 )
setParameter( MATERIAL, RMATNAME_TOP2, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_TOP2, "PLASTI/HARDI2/KAPSIG", [ 0, FY_10, EPSPLMAX2, SMAX_TOP2 ] )

addMaterial( RMATNAME_BOTTOM, "REINFO", "VMISES", [] )
setParameter( MATERIAL, RMATNAME_BOTTOM, "LINEAR/ELASTI/YOUNG", ESLONG1 )
setParameter( MATERIAL, RMATNAME_BOTTOM, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, RMATNAME_BOTTOM, "PLASTI/HARDI2/KAPSIG", [ 0, FY_12, EPSPLMAX3, SMAX_BOTTOM ] )

addMaterial( SMATNAME_HOR, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_HOR, "LINEAR/ELASTI/YOUNG", ESWEB_HOR )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_HOR, "PLASTI/HARDI2/KAPSIG", [ 0, FY_8, EPSPLMAX_WEB_HOR, SMAX_WEB_HOR ] )

addMaterial( SMATNAME_VERT, "REINFO", "VMISES", [] )
setParameter( MATERIAL, SMATNAME_VERT, "LINEAR/ELASTI/YOUNG", ESWEB_VERT )
setParameter( MATERIAL, SMATNAME_VERT, "PLASTI/YLDTYP", "KAPSIG" )
setParameter( MATERIAL, SMATNAME_VERT, "PLASTI/HARDI2/KAPSIG", [ 0, FY_8, EPSPLMAX_WEB_VERT, SMAX_WEB_VERT ] )

# ADD MATERIAL FOR REINFORCEMENT 
addGeometry( RMATNAME_BOTTOM, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_BOTTOM, "CROSSE", ASLBOTTOM )

addGeometry( RMATNAME_TOP1, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_TOP1, "CROSSE", ASLTOP1 )

addGeometry( RMATNAME_TOP2, "RELINE", "REBAR", [] )
setParameter( GEOMET, RMATNAME_TOP2, "CROSSE", ASLTOP2 )

addGeometry( SMATNAME_HOR, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_HOR, "CROSSE", ASSHOR )

addGeometry( SMATNAME_VERT, "RELINE", "REBAR", [] )
setParameter( GEOMET, SMATNAME_VERT, "CROSSE", ASSVERT )

#ASSIGN MATERIAL FOR REINFORCEMENT
assignMaterial( RMATNAME_BOTTOM, "SHAPE", LONGREINFBOTTOM )
assignGeometry( RMATNAME_BOTTOM, "SHAPE", LONGREINFBOTTOM )

assignMaterial( RMATNAME_TOP1, "SHAPE", LONGREINFTOP1 )
assignGeometry( RMATNAME_TOP1, "SHAPE", LONGREINFTOP1 )

assignMaterial( RMATNAME_TOP2, "SHAPE", LONGREINFTOP2 )
assignGeometry( RMATNAME_TOP2, "SHAPE", LONGREINFTOP2 )

assignMaterial( SMATNAME_HOR, "SHAPE", HOR_WEB1 )
assignGeometry( SMATNAME_HOR, "SHAPE", HOR_WEB1 )

assignMaterial( SMATNAME_HOR, "SHAPE", HOR_WEB2 )
assignGeometry( SMATNAME_HOR, "SHAPE", HOR_WEB2 )

assignMaterial( SMATNAME_VERT, "SHAPE", ASSTIRR_VERT )
assignGeometry( SMATNAME_VERT, "SHAPE", ASSTIRR_VERT )

# DEFINE SUPPORTS
createPointSupport( "LEFTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "TRANSL", [ 0, 1, 1 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "MIDSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "MIDSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "MIDSUPPORT", "TRANSL", [ 0, 1, 1] )
setParameter( GEOMETRYSUPPORT, "MIDSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "RIGHTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "TRANSL", [ 1, 1, 1] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

COORDLEFTSUPPORT = [XCOORD[2], YCOORD[0] , 0 ]
COORDMIDSUPPORT = [XCOORD[10], YCOORD[0], 0 ]
COORDRIGHTSUPPORT = [XCOORD[18], YCOORD[0] , 0 ]

attach( GEOMETRYSUPPORT, "LEFTSUPPORT", SHAPELIST[59], [COORDLEFTSUPPORT] )
attach( GEOMETRYSUPPORT, "MIDSUPPORT", SHAPELIST[63], [COORDMIDSUPPORT] )
attach( GEOMETRYSUPPORT, "RIGHTSUPPORT","SHEET67", [[ 2840, 0, 0 ]] )

#DEFINE SUPPORT IN LOADPLATES
addSet( GEOMETRYSUPPORTSET, "Loadsupport" )
createPointSupport( "Loadsupport", "Loadsupport" )
setParameter( GEOMETRYSUPPORT, "Loadsupport", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "Loadsupport", "TRANSL", [ 0, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "Loadsupport", "ROTATI", [ 0, 0, 0 ] )
attach( GEOMETRYSUPPORT, "Loadsupport", "SHEET61", [[ 820, 715, 0 ]] )
attach( GEOMETRYSUPPORT, "Loadsupport", "SHEET65", [[ 2180, 715, 0 ]] )

#DISPLACEMENT CONTROL 
addSet( GEOMETRYLOADSET, "Geometry load case 2" )
showView( "GEOM" )
createPointLoad( "Displacement control", "Geometry load case 2" )
setParameter( GEOMETRYLOAD, "Displacement control", "LODTYP", "DEFORM" )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/VALUE", PRESCRIBEDDISPLACEMENT )
setParameter( GEOMETRYLOAD, "Displacement control", "DEFORM/TR/DIRECT", 2 )
attach( GEOMETRYLOAD, "Displacement control", "SHEET61", [[ 820, 715, 0 ]] ) 
attach( GEOMETRYLOAD, "Displacement control", "SHEET65", [[ 2180, 715, 0 ]] )

# MESHING
setElementSize( SHAPELIST, ELEMENTSIZE )
setElementClassType( SHAPELIST, "MEMBRA" )
generateMesh(shapes())
addElementData( "Element data 1" )
setParameter( DATA, "Element data 1", "INTEGR", "HIGH" ) 
assignElementData( "Element data 1", ELEMENT, SHAPELIST )

# SET UP NON-LINEAR ANALYSIS
analysis = "project_RNR100LS_H12_3mm_damage-mc2010"
command  = "Structural nonlinear"
addAnalysis( analysis )
addAnalysisCommand( analysis, "NONLIN", command )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/METNAM", "NEWTON" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/NEWTON/TYPNAM", "REGULA" ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/MAXITE", 40 ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/DISPLA", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/TOLCON", 0.01 ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLCON", 0.001 ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/NOCONV", "CONTIN" ) 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/SIMULT", False )
# addAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE/CHOLES" )
addAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE" )   
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE", True )      
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/MAXLS", 10 )      

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/SIZES", "0.01(100)") 
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/AMOUNT", "FULL" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/TERMIN", "STEP" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELTYP", "USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/FORCE" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(2)/TOTAL/GREEN/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(3)/CRACK/GREEN" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(2)/TOTAL/CAUCHY/PRINCI/LOCATI", "INTPNT" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(4)/INCREM/TRANSL/GLOBAL" )


# EXPORT .DAT- AND .DCF-FILE
exportModel( "project.dat", 5 )
saveAnalysisCommands( analysis, "project.dcf")

# RUN ANALYSIS
runSolver( analysis )
showView( "RESULT" )
setViewPoint( "TOP" )
setResultPlot( "contours", "Cauchy Total Stresses/mappedintegrationpoint", "S2" )

# FIND LOAD DISPLACEMENT CURVE
DISPCOORD = [0.5*(XCOORD[2]+XCOORD[10]),YCOORD[1], 0 ]
DISPNODE = findNearestNodes([DISPCOORD])

FORCENODE1 = findNearestNodes([COORDLEFTSUPPORT])
FORCENODE2 = findNearestNodes([COORDMIDSUPPORT])
FORCENODE3 = findNearestNodes([COORDRIGHTSUPPORT])
FORCENODES = [FORCENODE1[0],FORCENODE2[0],FORCENODE3[0]]

DISPLACEMENTS = []
LASTCASE = len(resultCases(analysis,''))
for i in range(0,LASTCASE):
    DISPLACEMENTS.append(resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Displacements","TDtY"],DISPNODE)[0][1])

REACTIONS = []
FORCE = 0
for i in range(0,LASTCASE):
    for j in FORCENODES:
        FORCE = FORCE + resultData([analysis,"Output",resultCases(analysis,"Output")[i],"Reaction Forces","FBY"],(j,))[0][1]
    REACTIONS.append(FORCE)  
    FORCE = 0 
f = open('LOADDISP_project.TXT','w')
for i in range(0,len(REACTIONS)):
    f.write('{0:20.6f} {1:20.6f}\n'.format(DISPLACEMENTS[i],REACTIONS[i]))

f.close()


